pub struct ZcosmicToplevelHandleV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
an open toplevel
A zcosmic_toplevel_handle_v1 object represents an open toplevel window. A single app may have multiple open toplevels.
Each toplevel has a list of outputs it is visible on, exposed to the client via the output_enter and output_leave events.
See also the Event enum for this interface.
Implementations